@@ -12,6 +12,6 @@ However, trailing underscores have special meaning for referencing, thus
     $ flake8 --select RST RST217/roles.py
     RST217/roles.py:10:1: RST17 Mismatch: both interpreted text role suffix and reference suffix.
 
-"""
+"""  # noqa: E501
 
 print("Hello world")
